import{d as S,S as h,v as w,u as x,f as r,aJ as D,al as B,bv as R,j as T,g as l,c,o as n,h as a,i as V,m as t,a6 as j,a as o,cy as z,cz as u,cA as A,bg as I}from"./index-B8dvxl4J.js";import{u as N}from"./usePageTitle-BP6ee6do.js";const W=S({__name:"ConcurrencyLimit",setup(J){const m=h(),y=w("concurrencyLimitId"),p=x(),v=r(()=>[{label:"Details",hidden:D.xl},{label:"Active Task Runs"}]),s=B("tab","Details"),{tabs:d}=R(v,s),_={interval:3e5},b=T(m.concurrencyLimits.getConcurrencyLimit,[y.value],_),e=r(()=>b.response);function f(){p.push(I.concurrencyLimits())}const L=r(()=>e.value?`Concurrency Limit: ${e.value.tag}`:"Concurrency Limit");return N(L),(O,i)=>{const C=l("p-tabs"),k=l("p-layout-well");return n(),c(k,{class:"concurrencyLimit"},{header:a(()=>[e.value?(n(),c(t(A),{key:0,"concurrency-limit":e.value,onDelete:f},null,8,["concurrency-limit"])):o("",!0)]),well:a(()=>[e.value?(n(),c(t(u),{key:0,alternate:"","concurrency-limit":e.value},null,8,["concurrency-limit"])):o("",!0)]),default:a(()=>[V(C,{selected:t(s),"onUpdate:selected":i[0]||(i[0]=g=>j(s)?s.value=g:null),tabs:t(d)},{details:a(()=>[e.value?(n(),c(t(u),{key:0,"concurrency-limit":e.value},null,8,["concurrency-limit"])):o("",!0)]),"active-task-runs":a(()=>[e.value?.activeSlots?(n(),c(t(z),{key:0,"active-slots":e.value.activeSlots},null,8,["active-slots"])):o("",!0)]),_:1},8,["selected","tabs"])]),_:1})}}});export{W as default};
//# sourceMappingURL=ConcurrencyLimit-BsAGc1j0.js.map
