import{j as o}from"./vendor-tanstack-BVzzyDEt.js";import{c as s}from"./index-BJkJ93Lr.js";import{R as i}from"./route-error-state-BXl8358Q.js";import{W as m}from"./header-qLx9chqd.js";import"./vendor-react-Bce9NwRC.js";import"./vendor-radix-CTAic6HB.js";import"./vendor-recharts-Mwm2qLZp.js";import"./vendor-forms-BN3tpxM2.js";import"./vendor-date-2jFo9aCm.js";function E({error:e,reset:t}){const r=s(e,"Failed to load work pools");if(r.type!=="server-error"&&r.type!=="client-error")throw e;return o.jsxs("div",{className:"flex flex-col gap-4",children:[o.jsx(m,{}),o.jsx(i,{error:r,onRetry:t})]})}export{E as errorComponent};
//# sourceMappingURL=index-B06ywmp6.js.map
