import{r as t,j as e,L as o}from"./vendor-tanstack-BVzzyDEt.js";import{L as n}from"./lazy-markdown-CwRqR_1U.js";import{aJ as i,G as m,H as x,a3 as r,K as c,aU as d}from"./index-BJkJ93Lr.js";const f=({artifact:s,compact:a=!1})=>{const l=t.useMemo(()=>i(new Date(s.created??""),"dateTime"),[s.created]);return e.jsx(o,{to:"/artifacts/key/$key",params:{key:s.key??""},children:e.jsxs(m,{className:"hover:shadow-lg hover:border-blue-700",children:[e.jsx(x,{children:e.jsx(r,{variant:"bodySmall",className:"font-bold text-muted-foreground",children:s.type?.toUpperCase()})}),e.jsxs(c,{children:[e.jsxs("div",{className:d("flex",a?"flex-row justify-between":"flex-col"),children:[e.jsx(r,{variant:a?"h4":"h3",className:"font-bold",children:s.key}),e.jsxs("div",{className:d("flex mt-2",a?"flex-col-reverse items-end":"justify-between"),children:[e.jsx(r,{variant:a?"bodySmall":"xsmall",className:"",fontFamily:"mono",children:l}),e.jsx(r,{variant:"bodySmall",className:"text-muted-foreground",children:"Created"})]})]}),e.jsx("hr",{className:"my-2"}),s.description?e.jsx("div",{className:"text-muted-foreground overflow-hidden truncate",children:e.jsx(n,{children:s.description??""})}):e.jsx(r,{variant:"bodySmall",className:"text-muted-foreground italic",children:"No description"})]})]})})};export{f as A};
//# sourceMappingURL=artifact-card-Cy3v2Lds.js.map
