import{d as f,S as x,e as b,v as c,f as r,aD as h,aE as y,K as C,g as E,c as F,a as D,m as e,o as g,h as n,i as s,aF as k,A as w,aG as B}from"./index-B8dvxl4J.js";import{u as I}from"./usePageTitle-BP6ee6do.js";const j=f({__name:"Event",async setup(L){let a,o;const v=x(),l=b(),u=c("eventDate"),_=c("eventId"),m=r(()=>h(u.value)),d=y({startDate:m,eventId:[_.value]}),t=([a,o]=C(()=>v.events.getFirstEvent(d.value)),a=await a,o(),a),p=r(()=>[{text:"Event Feed",to:l.events()},{text:t.eventLabel}]);return I(`Event: ${t.eventLabel}`),(A,N)=>{const i=E("p-layout-default");return e(t)?(g(),F(i,{key:0,class:"event"},{header:n(()=>[s(e(w),{crumbs:p.value},{actions:n(()=>[s(e(B),{event:e(t)},null,8,["event"])]),_:1},8,["crumbs"])]),default:n(()=>[s(e(k),{event:e(t)},null,8,["event"])]),_:1})):D("",!0)}}});export{j as default};
//# sourceMappingURL=Event-g0saO35u.js.map
