import{f as a,m as c,by as n}from"./index-B8dvxl4J.js";function f(...t){const r=[...t,"Prefect Server"],o=a(()=>r.map(e=>c(e)).filter(e=>e!==null).join(" • "));n(()=>document.title=o.value)}export{f as u};
//# sourceMappingURL=usePageTitle-BP6ee6do.js.map
