import{j as e}from"./vendor-tanstack-BVzzyDEt.js";import{i as o,C as t,cn as g,bH as n,d0 as a}from"./index-BJkJ93Lr.js";const d={READY:e.jsx(a,{size:12,fill:"green"}),NOT_READY:e.jsx(a,{size:12,fill:"red"}),PAUSED:e.jsx(n,{size:12})},i=g("gap-2 px-2 text-foreground/80 font-mono font-light border border-foreground/10 shadow-none text-nowrap",{variants:{status:{READY:"bg-green-100 hover:bg-green-100 dark:bg-green-900 dark:hover:bg-green-900",NOT_READY:"bg-red-100 hover:bg-red-100 dark:bg-red-900 dark:hover:bg-red-900",PAUSED:"bg-gray-300 hover:bg-gray-300 dark:bg-gray-700 dark:hover:bg-gray-700"}}}),b=({status:r})=>d[r],l=({status:r})=>{const s=r.split("_").map(o).join(" ");return e.jsxs(t,{className:i({status:r}),children:[e.jsx(b,{status:r}),s]})};export{l as S,b as a};
//# sourceMappingURL=index-HTfhyme4.js.map
