import{j as e,s as c}from"./vendor-tanstack-BVzzyDEt.js";import{S as d,d as n,e as i,f as m,g as x,h as p,i as h,B as u,a as j,b as g,L as v,z as b,j as t,I as l,k as f,l as S}from"./index-BJkJ93Lr.js";import{u as N}from"./use-local-storage-BIDUVcfc.js";import{R as y,a as o}from"./radio-group-Bp8yWMIB.js";import"./vendor-react-Bce9NwRC.js";import"./vendor-radix-CTAic6HB.js";import"./vendor-recharts-Mwm2qLZp.js";import"./vendor-forms-BN3tpxM2.js";import"./vendor-date-2jFo9aCm.js";const C=["default","achromatopsia","deuteranopia","deuteranomaly","protaponia","protanomaly","tritanomaly","tritanopia"],k=()=>{const[s,r]=N("prefect-color-mode","default");return e.jsxs("div",{className:"flex flex-col gap-1",children:[e.jsx("label",{htmlFor:"color-mode-select",children:"Color Mode"}),e.jsxs(d,{value:s,onValueChange:a=>r(a),children:[e.jsx(n,{className:"w-96",id:"color-mode-select",children:e.jsx(i,{placeholder:"Select a color mode"})}),e.jsx(m,{children:e.jsx(x,{children:C.map(a=>e.jsx(p,{value:a,children:h(a)},a))})})]})]})},L=({version:s})=>e.jsxs("div",{className:"flex justify-between items-center",children:[e.jsx(u,{children:e.jsx(j,{children:e.jsx(g,{className:"text-xl font-semibold",children:"Settings"})})}),e.jsxs("div",{className:"flex flex-col gap-1",children:[e.jsx("div",{className:"text-xs text-muted-foreground",children:"Version"}),e.jsx("div",{className:"text-xs",children:s})]})]}),w=({settings:s})=>e.jsxs("div",{className:"flex flex-col gap-1",children:[e.jsx("label",{htmlFor:"server-settings",children:"Server Settings"}),e.jsx(v,{id:"server-settings",className:"p-2 rounded-sm",value:JSON.stringify(s,null,2),disabled:!0,hideLineNumbers:!0})]}),F=()=>{const{theme:s,setTheme:r}=b();return e.jsxs("div",{className:"flex flex-col gap-1",children:[e.jsx("label",{htmlFor:"color-mode-select",children:"Theme"}),e.jsx("div",{className:"space-y-3",children:e.jsxs(y,{value:s,onValueChange:r,className:"grid grid-cols-3 gap-4",children:[e.jsxs("div",{children:[e.jsx(o,{value:"light",id:"light",className:"peer sr-only"}),e.jsxs(t,{htmlFor:"light",className:"flex items-center space-x-2 rounded-md border-2 border-muted bg-popover p-4 hover:bg-accent hover:text-accent-foreground peer-data-[state=checked]:border-primary cursor-pointer",children:[e.jsx(l,{id:"Sun",className:"h-6 w-6"}),e.jsx("span",{children:"Light"})]})]}),e.jsxs("div",{children:[e.jsx(o,{value:"dark",id:"dark",className:"peer sr-only"}),e.jsxs(t,{htmlFor:"dark",className:"flex items-center space-x-2 rounded-md border-2 border-muted bg-popover p-4 hover:bg-accent hover:text-accent-foreground peer-data-[state=checked]:border-primary cursor-pointer",children:[e.jsx(l,{id:"Moon",className:"h-6 w-6"}),e.jsx("span",{children:"Dark"})]})]}),e.jsxs("div",{children:[e.jsx(o,{value:"system",id:"system",className:"peer sr-only"}),e.jsxs(t,{htmlFor:"system",className:"flex items-center space-x-2 rounded-md border-2 border-muted bg-popover p-4 hover:bg-accent hover:text-accent-foreground peer-data-[state=checked]:border-primary cursor-pointer",children:[e.jsx(l,{id:"Monitor",className:"h-6 w-6"}),e.jsx("span",{children:"System"})]})]})]})})]})},I=()=>{const{data:s}=c(f()),{data:r}=c(S());return e.jsxs("div",{className:"flex flex-col gap-4",children:[e.jsx(L,{version:r}),e.jsx(F,{}),e.jsx(k,{}),e.jsx(w,{settings:s})]})},Q=I;export{Q as component};
//# sourceMappingURL=settings-BxtO4J5H.js.map
