import{j as a}from"./vendor-tanstack-BVzzyDEt.js";import{cn as e}from"./index-BJkJ93Lr.js";const c=({alt:o,logoUrl:s,size:r="sm"})=>a.jsx("img",{alt:o,src:s??void 0,className:i({size:r})}),i=e("border-4 bg-gray-200 rounded",{variants:{size:{sm:"size-8",lg:"size-14"}}});export{c as B};
//# sourceMappingURL=block-type-logo-ESEG5U5y.js.map
