import{j as s,L as l,s as c}from"./vendor-tanstack-BVzzyDEt.js";import{B as m,a as d,b as o,bq as t,bz as n,G as x,a3 as i,q as u,cX as p,cY as j}from"./index-BJkJ93Lr.js";import{B as h}from"./block-type-logo-ESEG5U5y.js";import{P as f}from"./python-example-snippet-UamzIB5z.js";import{L as g}from"./lazy-markdown-CwRqR_1U.js";import"./vendor-react-Bce9NwRC.js";import"./vendor-radix-CTAic6HB.js";import"./vendor-recharts-Mwm2qLZp.js";import"./vendor-forms-BN3tpxM2.js";import"./vendor-date-2jFo9aCm.js";const B=({blockType:e})=>s.jsxs("div",{className:"flex flex-col gap-6",children:[s.jsx(N,{blockType:e}),s.jsx(v,{blockType:e})]});function N({blockType:e}){return s.jsx(m,{children:s.jsxs(d,{children:[s.jsx(o,{children:s.jsx(t,{to:"/blocks",className:"text-xl font-semibold",children:"Blocks"})}),s.jsx(n,{}),s.jsx(o,{children:s.jsx(t,{to:"/blocks/catalog",className:"text-xl font-semibold",children:"Catalog"})}),s.jsx(n,{}),s.jsx(o,{className:"text-xl font-semibold",children:e.slug})]})})}function v({blockType:e}){return s.jsx("div",{children:s.jsxs(x,{className:"p-6",children:[s.jsxs("div",{className:"flex items-center gap-4",children:[s.jsx(h,{size:"lg",logoUrl:e.logo_url}),s.jsx(i,{variant:"h3",children:e.name})]}),e.description&&s.jsx(b,{description:e.description,documentationUrl:e.documentation_url}),e.code_example&&s.jsxs("div",{className:"flex flex-col gap-4",children:[s.jsx(i,{variant:"h4",children:"Example"}),s.jsx(f,{codeExample:e.code_example,name:e.name})]}),s.jsx("div",{className:"flex justify-end",children:s.jsx(u,{children:s.jsx(l,{to:"/blocks/catalog/$slug/create",params:{slug:e.slug},children:"Create"})})})]})})}function b({description:e,documentationUrl:a}){let r=e;return a&&(r=`${r} [Documentation](${a})`),s.jsx("div",{className:"prose max-w-none",children:s.jsx(g,{children:r})})}function S(){const{slug:e}=p.useParams(),{data:a}=c(j(e));return s.jsx(B,{blockType:a})}export{S as component};
//# sourceMappingURL=catalog_._slug-Cl0fHR20.js.map
