import{d as r,g as s,c as n,o as l,h as e,i as o,m as a,d3 as p,d4 as u}from"./index-B8dvxl4J.js";import{u as _}from"./usePageTitle-BP6ee6do.js";const C=r({__name:"WorkPoolCreate",setup(c){return _("Create Work Pool"),(d,f)=>{const t=s("p-layout-default");return l(),n(t,null,{header:e(()=>[o(a(u))]),default:e(()=>[o(a(p))]),_:1})}}});export{C as default};
//# sourceMappingURL=WorkPoolCreate-DZHP5A1y.js.map
