import{d as D,S as T,v as $,j as h,f as p,ae as B,al as H,H as d,aH as I,g as n,c,o as l,h as e,p as R,a as i,i as s,m as t,aI as V,aJ as j,aK as _,D as P,t as z,aL as v,a6 as E,aM as m,aN as J}from"./index-B8dvxl4J.js";import{u as K}from"./usePageTitle-BP6ee6do.js";const L={key:0},G=D({__name:"Artifact",setup(M){const y=T(),b=$("artifactId"),k=h(y.artifacts.getArtifact,[b]),a=p(()=>k.response),r=B(!1),w=[{label:"Artifact"},{label:"Details"},{label:"Raw"}],u=H("tab","Artifact"),g=p(()=>a.value?`${d.info.artifact}: ${a.value.key??I(a.value.type)}`:d.info.artifact);return K(g),(U,o)=>{const x=n("p-divider"),C=n("p-button"),N=n("p-content"),S=n("p-tabs"),A=n("p-layout-well");return l(),c(A,{class:"artifact"},{header:e(()=>[a.value?(l(),c(t(J),{key:0,artifact:a.value},null,8,["artifact"])):i("",!0)]),well:e(()=>[a.value?(l(),c(t(m),{key:0,artifact:a.value,alternate:""},null,8,["artifact"])):i("",!0)]),default:e(()=>[a.value?(l(),R("section",L,[s(t(V),{artifact:a.value},null,8,["artifact"]),s(x),t(j).xl?(l(),c(N,{key:0},{default:e(()=>[s(t(_),{artifact:a.value},null,8,["artifact"]),s(C,{class:"artifact__raw-data-button",small:"",onClick:o[0]||(o[0]=f=>r.value=!r.value)},{default:e(()=>[P(z(r.value?"Hide":"Show")+" raw data ",1)]),_:1}),r.value?(l(),c(t(v),{key:0,artifact:a.value},null,8,["artifact"])):i("",!0)]),_:1})):(l(),c(S,{key:1,selected:t(u),"onUpdate:selected":o[1]||(o[1]=f=>E(u)?u.value=f:null),tabs:w},{artifact:e(()=>[s(t(_),{artifact:a.value},null,8,["artifact"])]),details:e(()=>[s(t(m),{artifact:a.value},null,8,["artifact"])]),raw:e(()=>[s(t(v),{artifact:a.value},null,8,["artifact"])]),_:1},8,["selected"]))])):i("",!0)]),_:1})}}});export{G as default};
//# sourceMappingURL=Artifact-B8yncesE.js.map
