import{j as t,L as o}from"./vendor-tanstack-BVzzyDEt.js";import{E as s,m as e,n,o as r,p as a,q as i}from"./index-BJkJ93Lr.js";import{b as m,f as p}from"./vendor-forms-BN3tpxM2.js";import"./vendor-react-Bce9NwRC.js";import"./vendor-radix-CTAic6HB.js";import"./vendor-recharts-Mwm2qLZp.js";import"./vendor-date-2jFo9aCm.js";function u(){return t.jsxs(s,{children:[t.jsx(e,{id:"Search"}),t.jsx(n,{children:"Flow Run Not Found"}),t.jsx(r,{children:"The flow run you are looking for does not exist or has been deleted."}),t.jsx(a,{children:t.jsx(i,{asChild:!0,children:t.jsx(o,{to:"/runs",children:"Back to Runs"})})})]})}m({tab:p(["Logs","TaskRuns","SubflowRuns","Artifacts","Details","Parameters","JobVariables"]).default("Logs").catch("Logs")});const y=u;export{y as notFoundComponent};
//# sourceMappingURL=flow-run._id-C8F8pjV6.js.map
