import{d as m,S as p,j as d,f as s,g as _,c as a,o as t,h as c,p as f,a as i,F as k,m as o,ch as h,ci as B,i as x,cj as y}from"./index-B8dvxl4J.js";import{u as C}from"./usePageTitle-BP6ee6do.js";const F=m({__name:"Blocks",setup(D){const n=p(),e=d(n.blockDocuments.getBlockDocumentsCount),l=s(()=>e.executed&&e.response==0),r=s(()=>e.executed);return C("Blocks"),(g,b)=>{const u=_("p-layout-default");return t(),a(u,{class:"blocks"},{header:c(()=>[x(o(y))]),default:c(()=>[r.value?(t(),f(k,{key:0},[l.value?(t(),a(o(h),{key:0})):(t(),a(o(B),{key:1,onDelete:o(e).refresh},null,8,["onDelete"]))],64)):i("",!0)]),_:1})}}});export{F as default};
//# sourceMappingURL=Blocks-BgNpDLct.js.map
