import{j as r}from"./vendor-tanstack-BVzzyDEt.js";import{c as s,B as a,a as i,b as m}from"./index-BJkJ93Lr.js";import{R as l}from"./route-error-state-BXl8358Q.js";import"./vendor-react-Bce9NwRC.js";import"./vendor-radix-CTAic6HB.js";import"./vendor-recharts-Mwm2qLZp.js";import"./vendor-forms-BN3tpxM2.js";import"./vendor-date-2jFo9aCm.js";function u({error:o,reset:t}){const e=s(o,"Failed to load variables");if(e.type!=="server-error"&&e.type!=="client-error")throw o;return r.jsxs("div",{className:"flex flex-col gap-4",children:[r.jsx("div",{className:"flex items-center gap-2",children:r.jsx(a,{children:r.jsx(i,{children:r.jsx(m,{className:"text-xl font-semibold",children:"Variables"})})})}),r.jsx(l,{error:e,onRetry:t})]})}export{u as errorComponent};
//# sourceMappingURL=variables-CUW4Ejrp.js.map
