import{d as f,ae as d,S as m,f as t,j as _,H as v,g as b,c as o,o as s,h as n,p as h,a as k,F as y,m as r,cG as C,cH as g,i as x,cI as S}from"./index-B8dvxl4J.js";import{u as V}from"./usePageTitle-BP6ee6do.js";const N=f({__name:"Variables",setup(B){const l=d(),e=()=>{a.value.refresh(),l.value?.refreshSubscriptions()},c=m(),a=t(()=>_(c.variables.getVariables)),u=t(()=>a.value.executed&&a.value.response?.length===0),p=t(()=>a.value.executed);return V(v.info.variables),(j,F)=>{const i=b("p-layout-default");return s(),o(i,{class:"variables"},{header:n(()=>[x(r(S),{onCreate:e})]),default:n(()=>[p.value?(s(),h(y,{key:0},[u.value?(s(),o(r(C),{key:0,onCreate:e})):(s(),o(r(g),{key:1,ref_key:"table",ref:l,onDelete:e,onUpdate:e},null,512))],64)):k("",!0)]),_:1})}}});export{N as default};
//# sourceMappingURL=Variables-DAJK2bj9.js.map
