import{j as o}from"./vendor-tanstack-BVzzyDEt.js";import{c as m}from"./index-BJkJ93Lr.js";import{D as p}from"./header-BAPAjM__.js";import{R as s}from"./route-error-state-BXl8358Q.js";import"./vendor-react-Bce9NwRC.js";import"./vendor-radix-CTAic6HB.js";import"./vendor-recharts-Mwm2qLZp.js";import"./vendor-forms-BN3tpxM2.js";import"./vendor-date-2jFo9aCm.js";function j({error:e,reset:t}){const r=m(e,"Failed to load deployments");if(r.type!=="server-error"&&r.type!=="client-error")throw e;return o.jsxs("div",{className:"flex flex-col gap-4",children:[o.jsx(p,{}),o.jsx(s,{error:r,onRetry:t})]})}export{j as errorComponent};
//# sourceMappingURL=index-CA73EClP.js.map
