import{u as l,r as d,j as s}from"./vendor-tanstack-BVzzyDEt.js";import{bp as p,bn as c,cR as m,U as f,N as b,d9 as y}from"./index-BJkJ93Lr.js";import{au as w,av as k,aw as Q}from"./vendor-radix-CTAic6HB.js";const I=()=>{const[{data:o},{data:r},{data:a},{data:u},{data:n},{data:i}]=l({queries:[p(),c(),m(),f(),b(),y()]});return{resourceOptions:d.useMemo(()=>{const t=[];for(const e of o??[])t.push({id:e.id,name:e.name,type:"automation",resourceId:`prefect.automation.${e.id}`});for(const e of r??[])t.push({id:e.id,name:e.name??"",type:"block",resourceId:`prefect.block-document.${e.id}`});for(const e of a??[])t.push({id:e.id,name:e.name,type:"deployment",resourceId:`prefect.deployment.${e.id}`});for(const e of u??[])t.push({id:e.id,name:e.name,type:"flow",resourceId:`prefect.flow.${e.id}`});for(const e of n??[])t.push({id:e.name,name:e.name,type:"work-pool",resourceId:`prefect.work-pool.${e.name}`});for(const e of i??[])t.push({id:e.id,name:e.name,type:"work-queue",resourceId:`prefect.work-queue.${e.id}`});return t},[o,r,a,u,n,i])}};function $({...o}){return s.jsx(w,{"data-slot":"collapsible",...o})}function j({...o}){return s.jsx(k,{"data-slot":"collapsible-trigger",...o})}function F({...o}){return s.jsx(Q,{"data-slot":"collapsible-content",...o})}export{$ as C,j as a,F as b,I as u};
//# sourceMappingURL=collapsible-B_Qn5IIc.js.map
