import{d as f,S as i,j as _,f as o,g as w,c as s,o as t,h as n,p as C,a as b,F as h,m as a,bO as k,bP as y,i as v,bQ as x}from"./index-B8dvxl4J.js";import{u as F}from"./usePageTitle-BP6ee6do.js";const N=f({__name:"Flows",setup(g){const l=i(),c={interval:3e4},e=_(l.flows.getFlowsCount,[{}],c),r=o(()=>e.response??0),u=o(()=>e.executed&&r.value===0),p=o(()=>e.executed),m=()=>{e.refresh()};return F("Flows"),(j,B)=>{const d=w("p-layout-default");return t(),s(d,{class:"flows"},{header:n(()=>[v(a(x))]),default:n(()=>[p.value?(t(),C(h,{key:0},[u.value?(t(),s(a(k),{key:0})):(t(),s(a(y),{key:1,selectable:"",onDelete:m}))],64)):b("",!0)]),_:1})}}});export{N as default};
//# sourceMappingURL=Flows-AznuJHuw.js.map
