import{d as i,S as b,u as d,v as _,f as o,bH as f,g as v,c as D,a as B,o as g,h as c,i as u,m as n,cu as h,cv as C,bg as S}from"./index-B8dvxl4J.js";import{u as w}from"./usePageTitle-BP6ee6do.js";const T=i({__name:"BlockView",setup(x){const s=b(),a=d(),t=_("blockDocumentId"),l=o(()=>t.value?[t.value]:null),r=f(s.blockDocuments.getBlockDocument,l),e=o(()=>r.response),m=()=>{a.push(S.blocks())},k=o(()=>e.value?`Block: ${e.value.name}`:"Block");return w(k),(y,N)=>{const p=v("p-layout-default");return e.value?(g(),D(p,{key:0,class:"block-view"},{header:c(()=>[u(n(C),{"block-document":e.value,onDelete:m},null,8,["block-document"])]),default:c(()=>[u(n(h),{"block-document":e.value},null,8,["block-document"])]),_:1})):B("",!0)}}});export{T as default};
//# sourceMappingURL=BlockView-ZvdOxoEt.js.map
