import{s as r,j as t}from"./vendor-tanstack-BVzzyDEt.js";import{db as m,B as l,a as c,b as s,bq as u,bz as d,bB as x,dt as j}from"./index-BJkJ93Lr.js";import{D as p}from"./delete-confirmation-dialog-Baib9xiM.js";import{u as b,A as f,a as g,b as h,c as A,d as D}from"./use-delete-automation-confirmation-dialog-tkKEViM0.js";import"./vendor-react-Bce9NwRC.js";import"./vendor-radix-CTAic6HB.js";import"./vendor-recharts-Mwm2qLZp.js";import"./vendor-forms-BN3tpxM2.js";import"./vendor-date-2jFo9aCm.js";import"./work-queue-icon-text-BMRtr4wA.js";import"./index-HTfhyme4.js";import"./use-delete-confirmation-dialog-DDTCxOIv.js";const B=({id:a})=>{const[o,i]=b(),{data:e}=r(m(a)),n=()=>i(e,{shouldNavigate:!0});return t.jsxs(t.Fragment,{children:[t.jsxs("div",{className:"flex flex-col gap-6",children:[t.jsxs("div",{className:"flex items-center justify-between",children:[t.jsx(N,{automation:e}),t.jsxs("div",{className:"flex items-center gap-2",children:[t.jsx(f,{automation:e}),t.jsx(g,{id:e.id,onDelete:n})]})]}),t.jsxs("div",{className:"flex flex-col gap-4",children:[t.jsx(h,{automation:e}),t.jsx(A,{automation:e}),t.jsx(D,{automation:e})]})]}),t.jsx(p,{...o})]})},N=({automation:a})=>t.jsx(l,{children:t.jsxs(c,{children:[t.jsx(s,{children:t.jsx(u,{to:"/automations",className:"text-xl font-semibold",children:"Automations"})}),t.jsx(d,{}),t.jsx(s,{className:"text-xl font-semibold",children:t.jsx(x,{children:a.name})})]})});function w(){const{id:a}=j.useParams();return t.jsx(B,{id:a})}export{w as component};
//# sourceMappingURL=automation._id-BRurAo6R.js.map
