import{j as a}from"./vendor-tanstack-BVzzyDEt.js";import{c as u,aI as i,ax as r,ce as n}from"./index-BJkJ93Lr.js";import{R as T}from"./route-error-state-BXl8358Q.js";import{b as t,f as o,n as e,e as l,c as p}from"./vendor-forms-BN3tpxM2.js";import"./vendor-react-Bce9NwRC.js";import"./vendor-radix-CTAic6HB.js";import"./vendor-recharts-Mwm2qLZp.js";import"./vendor-date-2jFo9aCm.js";t({tab:o(["Runs","Upcoming","Parameters","Configuration","Description"]).default("Runs"),runs:t({flowRuns:t({name:p().optional(),state:l(o(r)).optional().default(n).catch(n)}).optional(),page:e().int().positive().optional().default(1).catch(1),limit:e().int().positive().optional().default(10).catch(10),sort:o(i).optional().default("START_TIME_DESC").catch("START_TIME_DESC")}).optional(),upcoming:t({flowRuns:t({name:p().optional(),state:l(o(r)).optional().default(["Scheduled"]).catch(["Scheduled"])}).optional(),page:e().int().positive().optional().default(1).catch(1),limit:e().int().positive().optional().default(5).catch(5),sort:o(i).optional().default("START_TIME_ASC").catch("START_TIME_ASC")}).optional()});function y({error:s,reset:c}){const m=u(s,"Failed to load deployment");return a.jsxs("div",{className:"flex flex-col gap-4",children:[a.jsx("div",{children:a.jsx("h1",{className:"text-2xl font-semibold",children:"Deployment"})}),a.jsx(T,{error:m,onRetry:c})]})}export{y as errorComponent};
//# sourceMappingURL=deployment._id-Km7Ily8e.js.map
