import{j as e}from"./vendor-tanstack-BVzzyDEt.js";import{B as s,a as r,b as a}from"./index-BJkJ93Lr.js";const c=()=>e.jsx("div",{className:"flex items-center gap-2",children:e.jsx(s,{children:e.jsx(r,{children:e.jsx(a,{className:"text-xl font-semibold",children:"Deployments"})})})});export{c as D};
//# sourceMappingURL=header-BAPAjM__.js.map
