import{j as i,r as s}from"./vendor-tanstack-BVzzyDEt.js";import{ax as l,ay as c}from"./vendor-radix-CTAic6HB.js";import{cn as g,aU as d}from"./index-BJkJ93Lr.js";const v=g("inline-flex items-center justify-center gap-2 rounded-md text-sm font-medium hover:bg-muted hover:text-muted-foreground disabled:pointer-events-none disabled:opacity-50 data-[state=on]:bg-accent data-[state=on]:text-accent-foreground [&_svg]:pointer-events-none [&_svg:not([class*='size-'])]:size-4 [&_svg]:shrink-0 focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px] outline-none transition-[color,box-shadow] aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive whitespace-nowrap",{variants:{variant:{default:"bg-transparent",outline:"border border-input bg-transparent shadow-xs hover:bg-accent hover:text-accent-foreground"},size:{default:"h-9 px-2 min-w-9",sm:"h-8 px-1.5 min-w-8",lg:"h-10 px-2.5 min-w-10"}},defaultVariants:{variant:"default",size:"default"}}),u=s.createContext({size:"default",variant:"default"});function x({className:n,variant:e,size:t,children:a,...o}){return i.jsx(l,{"data-slot":"toggle-group","data-variant":e,"data-size":t,className:d("group/toggle-group flex w-fit items-center rounded-md data-[variant=outline]:shadow-xs",n),...o,children:i.jsx(u.Provider,{value:{variant:e,size:t},children:a})})}function b({className:n,children:e,variant:t,size:a,...o}){const r=s.useContext(u);return i.jsx(c,{"data-slot":"toggle-group-item","data-variant":r.variant||t,"data-size":r.size||a,className:d(v({variant:r.variant||t,size:r.size||a}),"min-w-0 flex-1 shrink-0 rounded-none shadow-none first:rounded-l-md last:rounded-r-md focus:z-10 focus-visible:z-10 data-[variant=outline]:border-l-0 data-[variant=outline]:first:border-l",n),...o,children:e})}export{x as T,b as a};
//# sourceMappingURL=toggle-group-B18EYoB-.js.map
