import{j as r}from"./vendor-tanstack-BVzzyDEt.js";import{c as s}from"./index-BJkJ93Lr.js";import{R as a}from"./route-error-state-BXl8358Q.js";import{b as i,f as m}from"./vendor-forms-BN3tpxM2.js";import"./vendor-react-Bce9NwRC.js";import"./vendor-radix-CTAic6HB.js";import"./vendor-recharts-Mwm2qLZp.js";import"./vendor-date-2jFo9aCm.js";i({tab:m(["Logs","TaskRuns","SubflowRuns","Artifacts","Details","Parameters","JobVariables"]).default("Logs").catch("Logs")});function R({error:o,reset:e}){const t=s(o,"Failed to load flow run");return r.jsxs("div",{className:"flex flex-col gap-4",children:[r.jsx("div",{children:r.jsx("h1",{className:"text-2xl font-semibold",children:"Flow Run"})}),r.jsx(a,{error:t,onRetry:e})]})}export{R as errorComponent};
//# sourceMappingURL=flow-run._id-OAXFFMfZ.js.map
