import{j as o}from"./vendor-tanstack-BVzzyDEt.js";import{c as i}from"./index-BJkJ93Lr.js";import{A as m}from"./automations-header-DhjvYQ5X.js";import{R as s}from"./route-error-state-BXl8358Q.js";import"./vendor-react-Bce9NwRC.js";import"./vendor-radix-CTAic6HB.js";import"./vendor-recharts-Mwm2qLZp.js";import"./vendor-forms-BN3tpxM2.js";import"./vendor-date-2jFo9aCm.js";function j({error:t,reset:e}){const r=i(t,"Failed to load automations");if(r.type!=="server-error"&&r.type!=="client-error")throw t;return o.jsxs("div",{className:"flex flex-col gap-4",children:[o.jsx(m,{}),o.jsx(s,{error:r,onRetry:e})]})}export{j as errorComponent};
//# sourceMappingURL=index-699gXUB-.js.map
