import{s as m,j as o}from"./vendor-tanstack-BVzzyDEt.js";import{cP as r,dO as s}from"./index-BJkJ93Lr.js";import{D as i}from"./deployment-action-header-f2FkVo9D.js";import{D as p}from"./deployment-form-CmIq2SZF.js";import"./vendor-react-Bce9NwRC.js";import"./vendor-radix-CTAic6HB.js";import"./vendor-recharts-Mwm2qLZp.js";import"./vendor-forms-BN3tpxM2.js";import"./vendor-date-2jFo9aCm.js";import"./lazy-schema-form-Clp5QfAW.js";import"./primitives-BxgEGUr4.js";import"./toggle-group-B18EYoB-.js";const n=({id:t})=>{const{data:e}=m(r(t));return o.jsxs("div",{className:"flex flex-col gap-4",children:[o.jsx(i,{deployment:e,action:"Edit"}),o.jsx(p,{deployment:e,mode:"edit"})]})};function R(){const{id:t}=s.useParams();return o.jsx(n,{id:t})}export{R as component};
//# sourceMappingURL=deployment_._id.edit-DgIOcfPL.js.map
