import{j as s}from"./vendor-tanstack-BVzzyDEt.js";import{B as o}from"./block-type-logo-ESEG5U5y.js";import{G as a,a3 as e}from"./index-BJkJ93Lr.js";import{L as i}from"./lazy-markdown-CwRqR_1U.js";function x({blockType:r}){return s.jsxs(a,{className:"p-6 max-h-60",children:[s.jsxs("div",{className:"flex items-center gap-4",children:[s.jsx(o,{size:"lg",logoUrl:r.logo_url}),s.jsx(e,{variant:"h4",children:r.name})]}),r.description&&s.jsx("div",{className:"prose max-w-none overflow-y-scroll text-sm",children:s.jsx(i,{children:r.description})})]})}export{x as B};
//# sourceMappingURL=block-type-details-CUkO-JbV.js.map
