import{d as c,S as k,v as l,K as w,g as _,c as d,o as i,h as r,i as n,m as o,dc as P,dd as f}from"./index-B8dvxl4J.js";import{u as Q}from"./usePageTitle-BP6ee6do.js";const x=c({__name:"WorkPoolQueueEdit",async setup(v){let e,u;const s=k(),a=l("workPoolName"),t=l("workPoolQueueName"),m=([e,u]=w(()=>s.workPoolQueues.getWorkPoolQueueByName(a.value,t.value)),e=await e,u(),e);return Q("Edit Work Pool Queue"),(N,h)=>{const p=_("p-layout-default");return i(),d(p,null,{header:r(()=>[n(o(f),{"work-pool-name":o(a),"work-pool-queue-name":o(t)},null,8,["work-pool-name","work-pool-queue-name"])]),default:r(()=>[n(o(P),{"work-pool-name":o(a),"work-pool-queue":o(m)},null,8,["work-pool-name","work-pool-queue"])]),_:1})}}});export{x as default};
//# sourceMappingURL=WorkPoolQueueEdit-uIw4gAD4.js.map
