import{d as m,S as y,v as _,j as k,f as s,H as o,g as v,c as e,o as t,h as n,a as r,p as d,m as c,aI as C,F as g,aO as h,aP as x}from"./index-B8dvxl4J.js";import{u as B}from"./usePageTitle-BP6ee6do.js";const P=m({__name:"ArtifactKey",setup(K){const l=y(),u=_("artifactKey"),i=k(l.artifacts.getArtifactCollection,[u]),a=s(()=>i.response),f=s(()=>a.value?`${o.info.artifact}: ${a.value.key}`:o.info.artifact);return B(f),(S,j)=>{const p=v("p-layout-default");return t(),e(p,{class:"artifact"},{header:n(()=>[a.value?(t(),e(c(x),{key:0,artifact:a.value},null,8,["artifact"])):r("",!0)]),default:n(()=>[a.value?(t(),e(c(C),{key:0,artifact:a.value},null,8,["artifact"])):r("",!0),a.value?(t(),d(g,{key:1},[a.value.key?(t(),e(c(h),{key:0,"artifact-key":a.value.key},null,8,["artifact-key"])):r("",!0)],64)):r("",!0)]),_:1})}}});export{P as default};
//# sourceMappingURL=ArtifactKey-BzKspcr-.js.map
