import{d,S as i,j as y,f as o,g as _,c as a,o as t,h as n,p as f,a as v,F as h,m as s,bX as k,bU as b,i as g,bY as x}from"./index-B8dvxl4J.js";import{u as D}from"./usePageTitle-BP6ee6do.js";const N=d({__name:"Deployments",setup(C){const l=i(),c={interval:3e4},e=y(l.deployments.getDeployments,[{}],c),p=o(()=>e.response??[]),r=o(()=>e.executed&&p.value.length===0),m=o(()=>e.executed);return D("Deployments"),(B,S)=>{const u=_("p-layout-default");return t(),a(u,{class:"deployments"},{header:n(()=>[g(s(x))]),default:n(()=>[m.value?(t(),f(h,{key:0},[r.value?(t(),a(s(k),{key:0})):(t(),a(s(b),{key:1,onDelete:s(e).refresh},null,8,["onDelete"]))],64)):v("",!0)]),_:1})}}});export{N as default};
//# sourceMappingURL=Deployments-Dj-yJlmg.js.map
